@@ -3,9 +3,9 @@ package Number::Phone::JP::Table::Class1;
 use strict;
 use warnings;
 
-our $VERSION = '0.20150901';
+our $VERSION = '0.20151202';
 
-# Table last modified: 2015-09-01
+# Table last modified: 2015-12-02
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '01'    => '\d+', # KDDI
@@ -19,8 +19,8 @@ our %TEL_TABLE = (
     '037'   => '\d+', # フュージョンコミュニケーションズ
     '038'   => '\d+', # フュージョンコミュニケーションズ
     '039'   => '\d+', # NTT西日本
-    '041'   => '\d+', # ソフトバンクモバイル
-    '046'   => '\d+', # ソフトバンクモバイル
+    '041'   => '\d+', # ソフトバンク
+    '046'   => '\d+', # ソフトバンク
     '050'   => '\d+', # アルテリア・ネットワークス
     '051'   => '\d+', # KDDI
     '052'   => '\d+', # KDDI
@@ -30,11 +30,11 @@ our %TEL_TABLE = (
     '056'   => '\d+', # KDDI
     '057'   => '\d+', # KDDI
     '060'   => '\d+', # アルテリア・ネットワークス
-    '061'   => '\d+', # ソフトバンクモバイル
-    '062'   => '\d+', # ソフトバンクモバイル
-    '063'   => '\d+', # ソフトバンクモバイル
-    '065'   => '\d+', # ソフトバンクモバイル
-    '066'   => '\d+', # ソフトバンクモバイル
+    '061'   => '\d+', # ソフトバンク
+    '062'   => '\d+', # ソフトバンク
+    '063'   => '\d+', # ソフトバンク
+    '065'   => '\d+', # ソフトバンク
+    '066'   => '\d+', # ソフトバンク
     '067'   => '\d+', # りーふねっと
     '070'   => '\d+', # KDDI
     '073'   => '\d+', # 安子の電話
@@ -43,10 +43,10 @@ our %TEL_TABLE = (
     '080'   => '\d+', # Tシステムズ・ジャパン
     '081'   => '\d+', # フュージョンコミュニケーションズ
     '082'   => '\d+', # フュージョンコミュニケーションズ
-    '083'   => '\d+', # ソフトバンクモバイル
-    '084'   => '\d+', # ソフトバンクモバイル
+    '083'   => '\d+', # ソフトバンク
+    '084'   => '\d+', # ソフトバンク
     '086'   => '\d+', # 九州通信ネットワーク
-    '088'   => '\d+', # ソフトバンクモバイル
+    '088'   => '\d+', # ソフトバンク
     '089'   => '\d+', # Tシステムズ・ジャパン
 );
 
